ete2.clustering.clustvalidation

Package ete2 :: Package clustering :: Module clustvalidation |
[hide private]
[frames] | no frames]

# Module clustvalidation

source code

Functions | [hide private]
safe_mean(values) Returns mean value discarding non finite values | source code
safe_mean_vector(vectors) Returns mean profile discarding non finite values. | source code
get_silhouette_width(fdist, cluster) | source code
get_avg_profile(node) This internal function updates the mean profile associated to an internal node. | source code
get_dunn_index(fdist, *clusters) Returns the Dunn index for the given selection of nodes. | source code
pearson_dist(v1, v2) | source code
spearman_dist(v1, v2) | source code
euclidean_dist(v1, v2) | source code
square_euclidean_dist(v1, v2) | source code
default_dist(v1, v2) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'``
| __package__ = ``'``ete2.clustering``'``

Function Details | [hide private]

### get_dunn_index(fdist, *clusters) | source code
Returns the Dunn index for the given selection of nodes. J.C. Dunn. Well separated clusters and optimal fuzzy partitions. 1974. J.Cybern. 4. 95-104.